@@ -41,6 +41,7 @@ from univention.config_registry import handler_set, handler_unset
 from univention.testing import udm as _udm
 from univention.testing.browser import logger
 from univention.testing.browser.generic_udm_module import UserModule
+from univention.testing.browser.ldap_directory import LDAPDirectory
 from univention.testing.browser.lib import UMCBrowserTest
 from univention.testing.browser.selfservice import SelfService
 from univention.testing.browser.sidemenu import SideMenuLicense, SideMenuUser
@@ -119,6 +120,11 @@ def self_service(umc_browser_test: UMCBrowserTest) -> SelfService:
     return SelfService(umc_browser_test)
 
 
+@pytest.fixture()
+def ldap_directory(umc_browser_test: UMCBrowserTest) -> LDAPDirectory:
+    return LDAPDirectory(umc_browser_test)
+
+
 @pytest.fixture(scope='module')
 def kill_module_processes():
     logger.info('killing module processes')
